@@ -32,8 +32,8 @@ tsData <- function(data,
   # Add beepvar:
   if (missing(beepvar)){
     beepvar <- "BEEP"
-    data <- data %>% dplyr::group_by_(dayvar,idvar) %>% 
-      dplyr::mutate_(BEEP = ~seq_len(n()))
+    data <- data %>% dplyr::group_by(.data[[dayvar]],.data[[idvar]]) %>% 
+      dplyr::mutate(BEEP = seq_len(n()))
   }
   
   # Vars:
@@ -51,13 +51,13 @@ tsData <- function(data,
   }
   
   # Obtain person specific means:
-  MeansData <- data %>% dplyr::group_by_(idvar) %>% dplyr::summarise_at(funs(mean(.,na.rm=TRUE)),.vars = vars)
+  MeansData <- data %>% dplyr::group_by(.data[[idvar]]) %>% dplyr::summarise_at(list(~mean(.,na.rm=TRUE)),.vars = vars)
   
   # Within-person center:
   if (centerWithin){
     # Only if N > 1 (very minimal floating point error can lead to different layout to older version otherwise)
     if (length(unique(data[[idvar]])) > 1){
-      data <- data %>% dplyr::group_by_(idvar) %>% dplyr::mutate_at(funs(scale(.,center=TRUE,scale=FALSE)),.vars = vars)          
+      data <- data %>% dplyr::group_by(.data[[idvar]]) %>% dplyr::mutate_at(funs(scale(.,center=TRUE,scale=FALSE)),.vars = vars)          
     }
   }
 
@@ -66,43 +66,54 @@ tsData <- function(data,
   augData <- data
   
   # Add missing rows for missing beeps
-  beepsPerDay <-  eval(substitute(dplyr::summarize_(data %>% group_by_(idvar,dayvar), 
-                                                    first = ~ min(beepvar,na.rm=TRUE),
-                                                    last = ~ max(beepvar,na.rm=TRUE)), 
-                                  list(beepvar = as.name(beepvar))))
+  # beepsPerDay <-  eval(substitute(dplyr::summarize_(data %>% group_by_(idvar,dayvar), 
+  #                                                   first = ~ min(beepvar,na.rm=TRUE),
+  #                                                   last = ~ max(beepvar,na.rm=TRUE)), 
+  #                                 list(beepvar = as.name(beepvar))))
   
+  beepsPerDay <-  dplyr::summarize(data %>% group_by(.data[[idvar]],.data[[dayvar]]), 
+                                                    first = min(.data[[beepvar]],na.rm=TRUE),
+                                                    last = max(.data[[beepvar]],na.rm=TRUE))
+ 
   # all beeps:
   allBeeps <- expand.grid(unique(data[[idvar]]),unique(data[[dayvar]]),seq(min(data[[beepvar]],na.rm=TRUE),max(data[[beepvar]],na.rm=TRUE))) 
   names(allBeeps) <- c(idvar,dayvar,beepvar)
   
   # Left join the beeps per day:
-  allBeeps <- eval(substitute({
-    allBeeps %>% dplyr::left_join(beepsPerDay, by = c(idvar,dayvar)) %>% 
-      dplyr::group_by_(idvar,dayvar) %>% dplyr::filter_(~BEEP >= first, ~BEEP <= last)%>%
-      dplyr::arrange_(idvar,dayvar,beepvar)
-  },  list(BEEP = as.name(beepvar))))
-
+  # allBeeps <- eval(substitute({
+  #   allBeeps %>% dplyr::left_join(beepsPerDay, by = c(idvar,dayvar)) %>% 
+  #     dplyr::group_by_(idvar,dayvar) %>% dplyr::filter_(~BEEP >= first, ~BEEP <= last)%>%
+  #     dplyr::arrange_(idvar,dayvar,beepvar)
+  # },  list(BEEP = as.name(beepvar))))
+  allBeeps <- allBeeps %>% dplyr::left_join(beepsPerDay, by = c(idvar,dayvar)) %>% 
+      dplyr::group_by(.data[[idvar]],.data[[dayvar]]) %>% dplyr::filter(.data[[beepvar]] >= .data$first, .data[[beepvar]] <= .data$last)%>%
+      dplyr::arrange(.data[[idvar]],.data[[dayvar]],.data[[beepvar]])
+  
   
   # Enter NA's:
-  augData <- augData %>% dplyr::right_join(allBeeps, by = c(idvar,dayvar,beepvar))
+  augData <- augData %>% dplyr::right_join(allBeeps, by = c(idvar,dayvar,beepvar)) %>%
+    arrange(.data[[idvar]],.data[[dayvar]],.data[[beepvar]])
   
   # Obtain data_c (slice away first row per day/subject):
-  data_c <- augData %>% ungroup %>% dplyr::select_(.dots = vars)#  %>% dplyr::group_by_(idvar,dayvar) %>% dplyr::slice(-1)
+  data_c <- augData %>% ungroup %>% dplyr::select(all_of(vars))
   
   # Lagged datasets:
   data_l <- do.call(cbind,lapply(lags, function(l){
-    data_lagged <- augData %>% dplyr::group_by_(idvar,dayvar) %>% dplyr::mutate_at(funs(shift),.vars = vars) %>% ungroup %>% dplyr::select_(.dots=vars)
+    data_lagged <- augData %>% dplyr::group_by(.data[[idvar]],.data[[dayvar]]) %>% dplyr::mutate_at(funs(shift),.vars = vars) %>% ungroup %>% dplyr::select(all_of(vars))
     names(data_lagged) <- paste0(vars,"_lag",l)
     data_lagged
   }))
   # data_l <- augData %>% dplyr::group_by_(idvar,dayvar) %>% dplyr::slice(-n())
-
   
   # # Remove rows with missings:
   if (deleteMissings){
     isNA <- rowSums(is.na(data_c)) > 0 | rowSums(is.na(data_l)) > 0
     data_c <- data_c[!isNA,]
     data_l <- data_l[!isNA,]
+    
+    if (nrow(data_l) == 0 || nrow(data_c) == 0){
+      stop("No data or all data has been deleted")
+    }
   }
 
   # Return datasets:
